@@ -29,6 +29,6 @@ sub format_time {
 sub format_log { sprintf($log_format, $_[0], format_time, join($log_bind, @{$bind_values || [$$]})) }
 
 $SIG{__WARN__} = sub { warn format_log($_[0]) };
-$SIG{__DIE__}  = sub { die  format_log($_[0]) if $^S };
+$SIG{__DIE__}  = sub { die  ref $_[0] ? $_[0] : format_log($_[0]) if $^S };
 
 1;
